@@ -15,7 +15,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '2.4-5'                              #
+# last changed in version = '2.4-6'                              #
 #                                                                # 
 ##################################################################
 
@@ -84,16 +84,16 @@ if [ "$1" == 'capture' ]; then
     echo "CAPTURE options were:" >> $tempLogging
     echo "   channel: $2 bssid: $3 writeto: $4/capturedData/$5/$6" >> $tempLogging
     echo " command given was:" >> $tempLogging
-    if [ "$5" == 'WPA' ]; then
-       echo "   airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0" >> $tempLogging
-    else
+    if [ "$5" == 'WEP' ]; then
        echo "   airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0" >> $tempLogging       
+    else
+       echo "   airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0" >> $tempLogging
     fi
 
-    if [ "$5" == 'WPA' ]; then
-       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
-    else
+    if [ "$5" == 'WEP' ]; then
        airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
+    else
+       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
     fi   
 fi 
 
@@ -104,7 +104,7 @@ if [ "$1" == 'authenticate' ]; then
     echo " command given was:" >> $tempLogging
     echo "   aireplay-ng -1 5 -q 10 -a $2 -h $3 wlan0" >> $tempLogging
  
-    aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
+    aireplay-ng -1 5 -q 10 -a $2 -h $3 wlan0
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
