@@ -260,7 +260,7 @@ class clevenCapture(QtGui.QMainWindow):
        self.ui.textBrowser.append('Ch: ' + channel + ', Priv.: ' + encryption + ', Pw: ' + power + 'dBm')
   
        essid_clean = essid
-       character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<'] 
+       character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<', '\'', '"', '[', ']', '{', '}', ',', '.', '~', '`'] 
        for i in character_list:
           essid_clean = essid_clean.replace(i,'_')
        print 'essid: ', essid, ' to essid (clean): ', essid_clean   
